Version 2.0.2 (2016-07-11)
--------------------------

- Fixed support for Python 2, patch by @lydell.


Version 2.0.1 (2015-11-10)
--------------------------

- Fixed dedenting not being applied to all nodes, patch by @andreif.


Version 2.0 (2015-11-06)
------------------------

- Refactored extension to support the `node` tag, see README for more details.


Version 1.0 (2015-06-30)
------------------------

- Initial release.
